@@ -1,4 +1,5 @@
 import os
+import re
 import json
 import logging
 import requests
@@ -6,6 +7,7 @@ import urllib.request
 from cloudpathlib import S3Client
 from botocore.exceptions import ClientError
 from cmapPy.pandasGEXpress.parse_gct import parse
+from os import environ
 from polly.errors import (
     error_handler,
     InvalidParameterException,
@@ -15,6 +17,24 @@ from polly.errors import (
     paramException,
 )
 from polly.constants import COHORT_CONSTANTS_URL
+import contextlib
+import joblib
+
+
+def get_platform_value_from_env(
+    variable: str, default_val: str, passed_val: str
+) -> str:
+    """
+    Get variable value of passed variable
+    from os env variables
+    """
+    if passed_val:
+        default_val = passed_val
+    elif environ.get(variable, None) is not None:
+        POLLY_TYPE = os.getenv(variable)
+        env_val = re.search("https://(.+?).elucidata.io", POLLY_TYPE)
+        default_val = env_val.group(1)
+    return default_val
 
 
 def make_path(prefix: any, postfix: any) -> str:
@@ -158,7 +178,7 @@ def get_data_type(self, url: str, payload: dict) -> str:
             detail="No matches found with the given repo details. Please try again.",
         )
     dataset = hits[0]
-    data_type = dataset.get("_source", {}).get("kw_data_type")
+    data_type = dataset.get("_source", {}).get("data_type")
     if not data_type:
         raise MissingKeyException("data_type")
     return data_type
@@ -206,3 +226,31 @@ def get_cohort_constants() -> json:
     response = requests.get(COHORT_CONSTANTS_URL)
     error_handler(response)
     return json.loads(response.text)
+
+
+def validate_datatype(datatype: str):
+    """
+    Function to validate datatype of a dataset
+    Returns 1 in case of datatype is Single Cell, 0 otherwise
+    """
+    if datatype == "Single cell":
+        return 1
+    return 0
+
+
+@contextlib.contextmanager
+def tqdm_joblib(tqdm_object):
+    """Context manager to patch joblib to report into tqdm progress bar given as argument"""
+
+    class TqdmBatchCompletionCallback(joblib.parallel.BatchCompletionCallBack):
+        def __call__(self, *args, **kwargs):
+            tqdm_object.update(n=self.batch_size)
+            return super().__call__(*args, **kwargs)
+
+    old_batch_callback = joblib.parallel.BatchCompletionCallBack
+    joblib.parallel.BatchCompletionCallBack = TqdmBatchCompletionCallback
+    try:
+        yield tqdm_object
+    finally:
+        joblib.parallel.BatchCompletionCallBack = old_batch_callback
+        tqdm_object.close()
