@@ -1,9 +1,11 @@
 import json
 import ssl
+import re
 import logging
 import os
 import platform
 import tempfile
+import csv
 from pathlib import Path
 from typing import Union, Dict
 from collections import namedtuple
@@ -11,9 +13,7 @@ import pandas as pd
 import requests
 from retrying import retry
 from polly.help import example, doc
-
 from polly import constants as const
-
 from polly import helpers
 from polly.auth import Polly
 from polly.constants import DATA_TYPES
@@ -61,7 +61,12 @@ converter functions.
     example = classmethod(example)
     doc = classmethod(doc)
 
-    def __init__(self, token=None, env="polly") -> None:
+    def __init__(self, token=None, env="", default_env="polly") -> None:
+        # check if COMPUTE_ENV_VARIABLE present or not
+        # if COMPUTE_ENV_VARIABLE, give priority
+        env = helpers.get_platform_value_from_env(
+            const.COMPUTE_ENV_VARIABLE, default_env, env
+        )
         self.session = Polly.get_session(token, env=env)
         self.base_url = f"https://v2.api.{self.session.env}.elucidata.io"
         self.discover_url = f"https://api.discover.{self.session.env}.elucidata.io"
@@ -349,6 +354,7 @@ converter functions.
 
         |  To know about quering metadata :ref:`Querying metadata <targetq>`.
         """
+
         max_page_size = 999
         if page_size is not None and page_size > max_page_size:
             raise ValueError(
@@ -500,11 +506,43 @@ converter functions.
         local_file_path = _local_temp_file_path(f"{query_id}.csv")
         _download_file_stream(results_file_download_url, local_file_path)
 
-        data_df = pd.read_csv(local_file_path)
+        columns_in_csv, conv_columns = self._get_columns_with_array_dtype(
+            local_file_path
+        )
+        list_conv = lambda x: x.strip("[]").split(",")
+        converter_dict = {}
+        for column_name in columns_in_csv:
+            if column_name in conv_columns:
+                converter_dict[column_name] = list_conv
+
+        data_df = pd.read_csv(local_file_path, converters=converter_dict)
+
         print(f"Fetched {len(data_df.index)} rows")
 
         return data_df
 
+    def _get_columns_with_array_dtype(self, local_file_path: str) -> list:
+        """
+        Return all the columns from the csv file
+        whose datatype is array
+        """
+        columns_in_csv = []
+        with open(local_file_path) as f:
+            reader = csv.reader(f)
+            columns_in_csv = next(reader)
+            dict_reader = csv.DictReader(f, delimiter=",", fieldnames=columns_in_csv)
+            conv_columns = []
+            for row in dict_reader:
+                for index in range(0, len(columns_in_csv)):
+                    key = columns_in_csv[index]
+                    val = row[key]
+                    if re.search(r"\[(.*?)\]", val):
+                        conv_columns.append(key)
+                    elif val == "[]":
+                        conv_columns.append(key)
+                break
+        return columns_in_csv, conv_columns
+
     def get_schema_from_api(
         self, repo_key: str, schema_type_dict: dict, source: str, data_type: str
     ) -> dict:
@@ -722,9 +760,6 @@ single cell datatype from an OmixAtlas, the user should use 'single_cell'.
         self, repo_key: str, schema_level=["dataset", "sample"], source="", data_type=""
     ) -> dict:
         """
-
-        :meta private:
-
         To visulize schema of a repository.
 
         ``Args:``
@@ -768,6 +803,8 @@ single cell datatype from an OmixAtlas, the user should use 'single_cell'.
             |              }
             |  iii) schema_type : gct_metadata i.e Row Fields (Feature)
             |  Not there right now
+
+        :meta private:
         """
         # get schema_type_dict
         schema_type_dict = self.get_schema_type(schema_level, data_type)
